@@ -85,7 +85,7 @@ def calculate_adjustment(df, cols = ['v_b_gene','j_b_gene'], adjcol = 'pVJ'):
     pd.Series
     """
     xdf = df[cols].groupby(cols).size().reset_index()
-    xdf.columns = ['v_b_gene','j_b_gene', 'n']
+    xdf.columns = cols + ['n']
     # For each V,J pairing compute frequency in this reference
     xdf['ref_freq'] = xdf['n'] / xdf['n'].sum()
     df = df.merge(xdf, how = "left", on = cols).reset_index()
@@ -198,7 +198,7 @@ def make_vj_matched_background(
             pass
     
     df = pd.concat(dfs).reset_index(drop = True)
-    df = df[df.cdr3_b_aa.notna()][cols]
+    df = df[df[cols[2]].notna()][cols]
     
     if ts is None:
         from tcrsampler.sampler import TCRsampler
@@ -424,7 +424,7 @@ def _synthesize_human_alpha_vj_background(ts,fn = None, df = None):
     # Subset columns
     df_target = df_target[['v_a_gene','j_a_gene','cdr3_a_aa']]
     # Make a gene usage counter
-    gene_usage_counter = make_gene_usage_counter(df_target)                             # 2
+    gene_usage_counter = make_gene_usage_counter(df_target, cols = ['v_a_gene', 'j_a_gene'])                             # 2
     print("MAKING A V-GENE, J-GENE MATCHED BACKGROUND.")
     # Check that sampler is using sample stratified frequencies. 
     assert ts.v_occur_freq is ts.v_occur_freq_stratified
@@ -441,7 +441,7 @@ def _synthesize_human_alpha_vj_background(ts,fn = None, df = None):
     df_vj_bkgd = df_vj_bkgd.sample(100000, random_state = 1).reset_index(drop = True)
     print("CALCULATE INVERSE PROBABILITY WEIGHT ADJUSTMENT.")
     # Calculate the invese weighting adjustmetn
-    df_vj_bkgd['weights'] = calculate_adjustment(df = df_vj_bkgd, adjcol = "pVJ")
+    df_vj_bkgd['weights'] = calculate_adjustment(df = df_vj_bkgd, adjcol = "pVJ", cols = ['v_a_gene','j_a_gene'])
     df_vj_bkgd['source'] = "vj_matched"
     # Combine
     return df_vj_bkgd
@@ -475,7 +475,7 @@ def _synthesize_mouse_beta_vj_background(ts, fn = None, df = None):
     # Subset columns
     df_target = df_target[['v_b_gene','j_b_gene','cdr3_b_aa']]
     # Make a gene usage counter
-    gene_usage_counter = make_gene_usage_counter(df_target)                             # 2
+    gene_usage_counter = make_gene_usage_counter(df_target, cols = ['v_b_gene', 'j_b_gene'])                             # 2
     print("MAKING A V-GENE, J-GENE MATCHED BACKGROUND.")
     # Check that sampler is using sample stratified frequencies. 
     assert ts.v_occur_freq is ts.v_occur_freq_stratified
@@ -496,3 +496,54 @@ def _synthesize_mouse_beta_vj_background(ts, fn = None, df = None):
     df_vj_bkgd['source'] = "vj_matched"
     # Combine
     return df_vj_bkgd
+
+def _synthesize_mouse_alpha_vj_background(ts, fn = None, df = None):
+    """
+    _build_vj_background
+
+    Parameters
+    ----------
+    ts: tcrsampler.TCRsampler() 
+        a TCRsampler instance, with gene usage frequencies (ideally computed get_stratified_gene_usage_frequency()
+    fn: str
+        file path to MIRA set of TCRs
+    df : pandas DataFrame
+        MIRA set of TCRs
+    Returns
+    -------
+    df_vj_bkgd : Pandas DataFrame
+        A set of background TCRs with the same V and J gene usage as the input set. 
+        These are generated using OLGA (Sethna et al.)
+    """
+    if fn is not None and df is not None:
+        raise ValueError("_build_vj_background can accept <df> or <fn> arguments but not both")
+    if fn is not None:
+        # Load a set set of TCRs.
+        df_target = pd.read_csv(fn)
+    if df is not None:
+        df_target = df.copy()
+    # Subset columns
+    df_target = df_target[['v_a_gene','j_a_gene','cdr3_a_aa']]
+    # Make a gene usage counter
+    gene_usage_counter = make_gene_usage_counter(df_target, cols = ['v_a_gene', 'j_a_gene'] )                             # 2
+    print("MAKING A V-GENE, J-GENE MATCHED BACKGROUND.")
+    # Check that sampler is using sample stratified frequencies. 
+    assert ts.v_occur_freq is ts.v_occur_freq_stratified
+    print("USING STRATIFIED FREQUENCIES.")
+    # Make a vj matched background. 
+    #   Note: <size> aregument should be greater than desired, because Olga can return none due to non-productive CDR3s.
+    df_vj_bkgd = make_vj_matched_background(ts = ts,
+        gene_usage_counter = gene_usage_counter,    
+        size = 150000, 
+        recomb_type="VJ", 
+        chain_folder = "mouse_T_alpha",
+        cols = ['v_a_gene', 'j_a_gene', 'cdr3_a_aa'])
+    # Sample to get the desired number of TCRs from teh v,j matched set
+    df_vj_bkgd = df_vj_bkgd.sample(100000, random_state = 1, replace = True).reset_index(drop = True)
+    print("CALCULATE INVERSE PROBABILITY WEIGHT ADJUSTMENT.")
+    print(df_vj_bkgd)
+    # Calculate the invese weighting adjustmetn
+    df_vj_bkgd['weights'] = calculate_adjustment(df = df_vj_bkgd, adjcol = "pVJ", cols = ['v_a_gene','j_a_gene'])
+    df_vj_bkgd['source'] = "vj_matched"
+    # Combine
+    return df_vj_bkgd
